@@ -48,9 +48,9 @@
 #include <KStandardAction>
 #include <KTar>
 
-#include <KStandardGameAction>
-#include <KgThemeSelector>
-#include <KgDifficulty>
+#include <KGameStandardAction>
+#include <KGameThemeSelector>
+#include <KGameDifficulty>
 
 #include "ksview.h"
 #include "gameactions.h"
@@ -156,7 +156,7 @@ KSudoku::KSudoku()
 
 	updateShapesList();
 
-	connect(Renderer::instance()->themeProvider(), &KgThemeProvider::currentThemeChanged, this, &KSudoku::updateSettings);
+	connect(Renderer::instance()->themeProvider(), &KGameThemeProvider::currentThemeChanged, this, &KSudoku::updateSettings);
 
 // 	QTimer *timer = new QTimer( this );
 // 	connect( timer, SIGNAL(timeout()), this, SLOT(updateStatusBar()) );
@@ -200,7 +200,7 @@ void KSudoku::updateShapesList()
     for (const QFileInfo &configFileInfo : std::as_const(filepaths)) {
 		const QDir variantDir = configFileInfo.dir();
 		KConfig variantConfig(configFileInfo.filePath(), KConfig::SimpleConfig);
-		KConfigGroup group = variantConfig.group ("KSudokuVariant");
+		KConfigGroup group = variantConfig.group (QStringLiteral("KSudokuVariant"));
 
 		variantName = group.readEntry("Name", i18n("Missing Variant Name")); // Translated.
 		variantDescr = group.readEntry("Description", ""); // Translated.
@@ -429,7 +429,7 @@ void KSudoku::dubPuzzle()
 			 "completely and correctly."), i18n("Check Puzzle"));
 	}
 
-	if(KMessageBox::questionYesNo(this, i18n("Do you wish to play the puzzle now?"), i18n("Play Puzzle"), KGuiItem(i18n("Play")), KStandardGuiItem::cancel() ) == KMessageBox::Yes)
+	if(KMessageBox::questionTwoActions(this, i18n("Do you wish to play the puzzle now?"), i18n("Play Puzzle"), KGuiItem(i18n("Play")), KStandardGuiItem::cancel() ) == KMessageBox::PrimaryAction)
 	{
 		startGame(ksudoku::Game(puzzle));
 	}
@@ -455,32 +455,32 @@ void KSudoku::setupActions()
 
 	setAcceptDrops(true);
 
-	KStandardGameAction::gameNew(this, SLOT(gameNew()), actionCollection());
-	KStandardGameAction::restart(this, SLOT(gameRestart()), actionCollection());
-	KStandardGameAction::load(this, SLOT(gameOpen()), actionCollection());
-	m_gameSave = KStandardGameAction::save(this, SLOT(gameSave()), actionCollection());
-	m_gameSaveAs = KStandardGameAction::saveAs(this, SLOT(gameSaveAs()), actionCollection());
- 	KStandardGameAction::print(this, SLOT(gamePrint()), actionCollection());
-	KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+	KGameStandardAction::gameNew(this, &KSudoku::gameNew, actionCollection());
+	KGameStandardAction::restart(this, &KSudoku::gameRestart, actionCollection());
+	KGameStandardAction::load(this, &KSudoku::gameOpen, actionCollection());
+	m_gameSave = KGameStandardAction::save(this, &KSudoku::gameSave, actionCollection());
+	m_gameSaveAs = KGameStandardAction::saveAs(this, &KSudoku::gameSaveAs, actionCollection());
+	KGameStandardAction::print(this, &KSudoku::gamePrint, actionCollection());
+	KGameStandardAction::quit(this, &KSudoku::close, actionCollection());
 	// TODO Export is disabled due to missing port to KDE4.
 // 	createAction("game_export", SLOT(gameExport()), i18n("Export"));
 
-	KStandardAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
+	KStandardAction::preferences(this, &KSudoku::optionsPreferences, actionCollection());
 	// Settings: enable messages that the user marked "Do not show again".
 	auto* enableMessagesAct = new QAction(i18n("Enable all messages"),this);
 	actionCollection()->addAction(QStringLiteral("enable_messages"), enableMessagesAct);
 	connect(enableMessagesAct, &QAction::triggered, this, &KSudoku::enableMessages);
 
 	//History
-	KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
-	KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
+	KGameStandardAction::undo(this, &KSudoku::undo, actionCollection());
+	KGameStandardAction::redo(this, &KSudoku::redo, actionCollection());
 
-	QAction * a = KStandardGameAction::hint(this, SLOT(giveHint()), actionCollection());
+	QAction * a = KGameStandardAction::hint(this, &KSudoku::giveHint, actionCollection());
 	// The default value (H) conflicts with the keys assigned
 	// to add letter/numbers to the board.
-	actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::Key_F2));
+	KActionCollection::setDefaultShortcut(a, QKeySequence(Qt::Key_F2));
 
-	KStandardGameAction::solve(this, SLOT(autoSolve()), actionCollection());
+	KGameStandardAction::solve(this, &KSudoku::autoSolve, actionCollection());
 
 	a = new QAction(this);
 	actionCollection()->addAction( QStringLiteral( "move_dub_puzzle" ), a);
@@ -493,28 +493,28 @@ void KSudoku::setupActions()
 void KSudoku::setupStatusBar (int difficulty, int symmetry)
 {
 	// Use the standard combo box for difficulty, from KDE Games library.
-	Kg::difficulty()->addStandardLevelRange(KgDifficultyLevel::VeryEasy, KgDifficultyLevel::Hard);
+	KGameDifficulty::global()->addStandardLevelRange(KGameDifficultyLevel::VeryEasy, KGameDifficultyLevel::Hard);
 	// and add our custom ones
 	enum CustomHardness {
-	    DiabolicalHardness = KgDifficultyLevel::Hard + 1,
+	    DiabolicalHardness = KGameDifficultyLevel::Hard + 1,
 	    UnlimitedHardness
 	};
-	Kg::difficulty()->addLevel(new KgDifficultyLevel(DiabolicalHardness, "Diabolical",
+	KGameDifficulty::global()->addLevel(new KGameDifficultyLevel(DiabolicalHardness, "Diabolical",
 		i18nc("A level of difficulty in Sudoku puzzles", "Diabolical")));
-	Kg::difficulty()->addLevel(new KgDifficultyLevel(UnlimitedHardness, "Unlimited",
+	KGameDifficulty::global()->addLevel(new KGameDifficultyLevel(UnlimitedHardness, "Unlimited",
 		i18nc("A level of difficulty in Sudoku puzzles", "Unlimited")));
 
 	// Set default value of difficulty
-	const KgDifficultyLevel * level = Kg::difficulty()->levels().value(difficulty);
+	const KGameDifficultyLevel * level = KGameDifficulty::global()->levels().value(difficulty);
 	if (level) {
-	    Kg::difficulty()->select(level);
+	    KGameDifficulty::global()->select(level);
 	}
 
-	connect(Kg::difficulty(), &KgDifficulty::currentLevelChanged,
+	connect(KGameDifficulty::global(), &KGameDifficulty::currentLevelChanged,
 		this, &KSudoku::handleCurrentDifficultyLevelChanged);
 
 	statusBar()->addPermanentWidget (new QLabel (i18nc("@option drop down box", "Difficulty:")));
-	KgDifficultyGUI::init(this);
+	KGameDifficultyGUI::init(this);
 
 	// Set up a combo box for symmetry of puzzle layout.
 	statusBar()->addPermanentWidget (new QLabel (i18nc("@option drop down box", "Symmetry:")));
@@ -540,38 +540,38 @@ void KSudoku::adaptActions2View() {
 
 	m_gameSave->setEnabled(game.isValid());
 	m_gameSaveAs->setEnabled(game.isValid());
-	action("game_new")->setEnabled(game.isValid());
-	action("game_restart")->setEnabled(game.isValid());
-	action("game_print")->setEnabled(game.isValid());
+	action(QStringLiteral("game_new"))->setEnabled(game.isValid());
+	action(QStringLiteral("game_restart"))->setEnabled(game.isValid());
+	action(QStringLiteral("game_print"))->setEnabled(game.isValid());
 	if(game.isValid()) {
 		bool isEnterPuzzleMode = !game.puzzle()->hasSolution();
-		action("move_hint")->setVisible(!isEnterPuzzleMode);
-		action("move_solve")->setVisible(!isEnterPuzzleMode);
-		action("move_dub_puzzle")->setVisible(isEnterPuzzleMode);
+		action(QStringLiteral("move_hint"))->setVisible(!isEnterPuzzleMode);
+		action(QStringLiteral("move_solve"))->setVisible(!isEnterPuzzleMode);
+		action(QStringLiteral("move_dub_puzzle"))->setVisible(isEnterPuzzleMode);
 
-		action("move_undo")->setEnabled(game.canUndo());
-		action("move_redo")->setEnabled(game.canRedo());
+		action(QStringLiteral("move_undo"))->setEnabled(game.canUndo());
+		action(QStringLiteral("move_redo"))->setEnabled(game.canRedo());
 
-		action("move_hint")      ->setEnabled(   game.puzzle()->hasSolution());
-		action("move_solve")     ->setEnabled(   game.puzzle()->hasSolution());
-		action("move_dub_puzzle")->setEnabled( ! game.puzzle()->hasSolution());
+		action(QStringLiteral("move_hint"))      ->setEnabled(   game.puzzle()->hasSolution());
+		action(QStringLiteral("move_solve"))     ->setEnabled(   game.puzzle()->hasSolution());
+		action(QStringLiteral("move_dub_puzzle"))->setEnabled( ! game.puzzle()->hasSolution());
 	} else {
-		action("move_undo")->setEnabled(false);
-		action("move_redo")->setEnabled(false);
+		action(QStringLiteral("move_undo"))->setEnabled(false);
+		action(QStringLiteral("move_redo"))->setEnabled(false);
 
-		action("move_hint")->setVisible(false);
-		action("move_solve")->setVisible(false);
-		action("move_dub_puzzle")->setVisible(false);
+		action(QStringLiteral("move_hint"))->setVisible(false);
+		action(QStringLiteral("move_solve"))->setVisible(false);
+		action(QStringLiteral("move_dub_puzzle"))->setVisible(false);
 	}
 }
 
 void KSudoku::onModified(bool /*isModified*/) {
 	Game game = currentGame();
 	if(game.isValid()) {
-		action("move_undo")->setEnabled(game.canUndo());
-		action("move_redo")->setEnabled(game.canRedo());
-		action("move_hint")->setEnabled(!game.allValuesSetAndUsable());
-		action("move_solve")->setEnabled(!game.wasFinished());
+		action(QStringLiteral("move_undo"))->setEnabled(game.canUndo());
+		action(QStringLiteral("move_redo"))->setEnabled(game.canRedo());
+		action(QStringLiteral("move_hint"))->setEnabled(!game.allValuesSetAndUsable());
+		action(QStringLiteral("move_solve"))->setEnabled(!game.wasFinished());
 	}
 }
 
@@ -582,7 +582,7 @@ void KSudoku::undo() {
 	game.interface()->undo();
 
 	if(!game.canUndo()) {
-		action("move_undo")->setEnabled(false);
+		action(QStringLiteral("move_undo"))->setEnabled(false);
 	}
 }
 
@@ -593,7 +593,7 @@ void KSudoku::redo() {
 	game.interface()->redo();
 
 	if(!game.canRedo()) {
-		action("move_redo")->setEnabled(false);
+		action(QStringLiteral("move_redo"))->setEnabled(false);
 	}
 }
 
@@ -650,11 +650,11 @@ void KSudoku::gameNew()
 
 	// only show question when the current game hasn't been finished until now
 	if(!m_gameUI->game().wasFinished()) {
-		if(KMessageBox::questionYesNo(this,
+		if(KMessageBox::questionTwoActions(this,
 	                              i18n("Do you really want to end this game in order to start a new one?"),
 	                              i18nc("window title", "New Game"),
 	                              KGuiItem(i18nc("button label", "New Game")),
-	                              KStandardGuiItem::cancel() ) != KMessageBox::Yes)
+	                              KStandardGuiItem::cancel() ) != KMessageBox::PrimaryAction)
 			return;
 	}
 
@@ -669,11 +669,11 @@ void KSudoku::gameRestart()
 
 	// only show question when the current game hasn't been finished until now
 	if (!game.wasFinished()) {
-		if (KMessageBox::questionYesNo(this,
+		if (KMessageBox::questionTwoActions(this,
                                 i18n("Do you really want to restart this game?"),
                                 i18nc("window title", "Restart Game"),
                                 KGuiItem(i18nc("button label", "Restart Game")),
-                                KStandardGuiItem::cancel() ) != KMessageBox::Yes) {
+                                KStandardGuiItem::cancel() ) != KMessageBox::PrimaryAction) {
 			return;
 		}
 	}
@@ -781,7 +781,7 @@ void KSudoku::optionsPreferences()
 
 	auto* gameConfig = new GameConfig();
 	dialog->addPage(gameConfig, i18nc("Game Section in Config", "Game"), QStringLiteral("games-config-options"));
-	dialog->addPage(new KgThemeSelector(Renderer::instance()->themeProvider()), i18n("Theme"), QStringLiteral("games-config-theme"));
+	dialog->addPage(new KGameThemeSelector(Renderer::instance()->themeProvider()), i18n("Theme"), QStringLiteral("games-config-theme"));
 
     //QT5 dialog->setHelp(QString(),"ksudoku");
 	connect(dialog, &KConfigDialog::settingsChanged, this, &KSudoku::updateSettings);
@@ -800,9 +800,9 @@ void KSudoku::updateSettings() {
 	Q_EMIT settingsChanged();
 }
 
-void KSudoku::handleCurrentDifficultyLevelChanged(const KgDifficultyLevel *level)
+void KSudoku::handleCurrentDifficultyLevelChanged(const KGameDifficultyLevel *level)
 {
-    const int difficulty = Kg::difficulty()->levels().indexOf(level);
+    const int difficulty = KGameDifficulty::global()->levels().indexOf(level);
 
     if (difficulty == -1) {
 	return;
@@ -858,11 +858,14 @@ ksudoku::KsView* KSudoku::currentView() const{
 void KSudoku::enableMessages()
 {
 	// Enable all messages that the user has marked "Do not show again".
-	int result = KMessageBox::questionYesNo(this,
+	int result = KMessageBox::questionTwoActions(this,
 					i18n("This will enable all the dialogs that you had disabled by marking "
 						 "the 'Do not show this message again' option.\n\n"
-						 "Do you want to continue?"));
-	if (result == KMessageBox::Yes) {
+						 "Do you want to continue?"),
+					QString(),
+					KGuiItem(i18nc("@action:button", "Enable")),
+					KStandardGuiItem::cancel());
+	if (result == KMessageBox::PrimaryAction) {
 		KMessageBox::enableAllMessages();
 		KSharedConfig::openConfig()->sync();	// Save the changes to disk.
 	}
